
set more off

*****************************************
*           CASEN 2009
*****************************************
set more off
clear all
use "$inputs/casen2009stata.dta", clear  // Codigo 2008 and 2009


drop if segmento==.  // There is one observations which is missing for all

*=========
* Labels
*=========

* Labels yes/no
label define yn 1 "Yes" 0 "No"


* Labels for regions
label define regions_lab 1 "Tarapacá" 2 "Antofagasta" 3 "Atacama" 4 "Coquimbo" 5 "Valparaíso" 6 "O'higgins" 7 "Maule" 8 "Bío Bío" ///
9 "La Araucanía" 10 "Los Lagos" 11 "Aysén" 12 "Magallanes" 13 "Metropolitana Santiago" 14 "Los Ríos" 15 "Arica y Parinacota"
label values region regions_lab 


* Family Parenting Labels
label define parentesco1 1 "jefe(a) de hogar" 2 "esposo(a)/pareja" 3 "hijo(a) de ambos" 4 "hijo(a) sólo del jefe" 5 "hijo(a) sólo del esposo(a)pareja" ///
6 "padre o madre" 7 "suegro(a)" 8 "yerno o nuera" 9 "nieto(a)" 10 "hermano(a)" 11 "cuñado(a)" 12 "otro familiar" 13 "no familiar" 14 "servicio doméstico puertas adentro"
label values pco1 parentesco1

label define parentesco2 1 "jefe(a) de núcleo" 2 "esposo(a) / pareja" 3 "hijo(a) de ambos" 4 "hijo(a) sólo del jefe" 5 "hijo(a) sólo del esposo(a) / pareja" 12 "otro familiar" 13 "no familiar"
label values pco2 parentesco2


*=============================
* Geographical
*=============================

* Create codes for region, province and commune where live now
gen codreg_v =region
label var codreg_v "Region of residence"

gen codprov_v=provincia
label var codprov_v "Province of residence"

gen codcom_v =comuna
label var codcom_v "Commune of residence"


* Create codes for region, province and commune where works
gen codcom_c= t10cod
destring codcom_c, replace
replace codcom_c=codcom_v if codcom_c==.
label var codcom_c "Commune where individuals works"

gen codcom_c2=codcom_c
tostring codcom_c2, replace
gen codprov_c=substr(codcom_c2,1,2) if length(codcom_c2)==4
replace codprov_c=substr(codcom_c2,1,3) if length(codcom_c2)==5
label var codprov_c "Province where work"

gen codreg_c =substr(codcom_c2,1,1) if length(codcom_c2)==4
replace codreg_c=substr(codcom_c2,1,2) if length(codcom_c2)==5
label var codreg_c  "Region where work"

destring codreg_c codprov_c, replace
drop codcom_c2


* Macroregions
gen r_norte   =(region==1 | region==2 | region==3 | region==4 | region==5 | region==15)
label var r_norte "Macroregión Norte"
gen r_santiago=(region==13)
label var r_santiago "Santiago"
gen r_sur     =(region==6 | region==7 | region==8 | region==9 | region==10 | region==11 | region==12 | region==14)
label var r_sur "Macroregion Sur"


* Zone
recode zona (1 = 1 "Urban") (2 = 0 "Rural"), gen(urban)
label var urban "Zone"



*=============================
* Commuting Codes
*=============================

* Commuting by region 
gen commute_reg=((codcom_v!=codcom_c) & (codreg_c!=codreg_v))
label values commute_reg yn
label var commute_reg "Commuting by region"


* Commuting by province
gen commute_prov=((codcom_v!=codcom_c) & (codprov_c!=codprov_v))
label values commute_prov yn
label var commute_prov "Commuting by province"


* Commuting by commune
recode t10 (2=1 "Yes") (1 3 =0 "No") (9=.), gen(commute)
label var commute "Commute"


* Functional Areas Codes
gen af_v = codcom_v
label var af_v "Functional area of residence"
gen af_t = codcom_c
label var af_t "Functional area of work"


* CONURBACIONES
*---------------
{
* Region 1: Tarapacá
gl gran_iquique  "1101 1107"
foreach a of global gran_iquique {
	replace af_v = 1 if codcom_v == `a'
	replace af_t = 1 if codcom_c == `a'
}
* Region 4: Coquimbo
gl gran_laserena "4101 4102"
foreach a of global gran_laserena {
	replace af_v = 2 if codcom_v == `a'
	replace af_t = 2 if codcom_c == `a'
}
gl vicuna "4106"
foreach a of global vicuna {
	replace af_v = 3 if codcom_v == `a'
	replace af_t = 3 if codcom_c == `a'
}
* Region 5: Valparaíso
gl gran_valparaiso "5101 5103 5109 5106 5108"
foreach a of global gran_valparaiso {
	replace af_v = 4 if codcom_v == `a'
	replace af_t = 4 if codcom_c == `a'
} 
gl quillota  "5501 5502 5504"
foreach a of global quillota {
	replace af_v = 5 if codcom_v == `a'
	replace af_t = 5 if codcom_c == `a'
}
gl limache "5505 5507"
foreach a of global limache {
	replace af_v = 6 if codcom_v == `a'
	replace af_t = 6 if codcom_c == `a'
}
gl sanantonio  "5601 5603 5605 5606"
foreach a of global sanantonio {
	replace af_v = 7 if codcom_v == `a'
	replace af_t = 7 if codcom_c == `a'
}
gl elquisco "5602 5604 5605"
foreach a of global elquisco {
	replace af_v = 8 if codcom_v == `a'
	replace af_t = 8 if codcom_c == `a'
}
gl sanfelipe "5701 5706"
foreach a of global sanfelipe {
	replace af_v = 9 if codcom_v == `a'
	replace af_t = 9 if codcom_c == `a'
}
* Region 6: O'Higgins
gl rancagua  "6101 6108 6111"
foreach a of global rancagua {
	replace af_v = 10 if codcom_v == `a'
	replace af_t = 10 if codcom_c == `a'
}
gl santacruz  "6306 6310"
foreach a of global santacruz {
	replace af_v = 11 if codcom_v == `a'
	replace af_t = 11 if codcom_c == `a'
}
* Region 7: Maule
gl talca  "7101 7105"
foreach a of global talca {
	replace af_v = 12 if codcom_v == `a'
	replace af_t = 12 if codcom_c == `a'
}
* Region 8: Biobio
gl gran_concepcion "8101 8102 8103 8105 8106 8107 8108 8110 8111 8112" 
foreach a of global gran_concepcion {
	replace af_v = 13 if codcom_v == `a'
	replace af_t = 13 if codcom_c == `a'
}
gl losalamos  "8206"
foreach a of global losalamos {
	replace af_v = 14 if codcom_v == `a'
	replace af_t = 14 if codcom_c == `a'
}
gl lalaja  "8304 8310"
foreach a of global lalaja {
	replace af_v = 15 if codcom_v == `a'
	replace af_t = 15 if codcom_c == `a'
}
gl chillan  "8401 8406"
foreach a of global chillan {
	replace af_v = 16 if codcom_v == `a'
	replace af_t = 16 if codcom_c == `a'
}
* Region 9: La Araucanía
gl gran_temuco  "9101 9112"
foreach a of global gran_temuco {
	replace af_v = 17 if codcom_v == `a'
	replace af_t = 17 if codcom_c == `a'
}
* Region 10: Los Lagos
gl mansa "10306"
foreach a of global mansa {
	replace af_v = 18 if codcom_v == `a'
	replace af_t = 18 if codcom_c == `a'
}
gl puertomontt  "10101 10109"
foreach a of global puertomontt {
	replace af_v = 19 if codcom_v == `a'
	replace af_t = 19 if codcom_c == `a'
}
* Region 13: Gran Santiago
gl gran_santiago "13101 13102 13103 13104 13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13201 13202 13203 13401 13604" // si esta bien
foreach a of global gran_santiago {
	replace af_v = 20 if codcom_v == `a'
	replace af_t = 20 if codcom_c == `a'
}
gl lacolina  "13301"
foreach a of global lacolina {
	replace af_v = 21 if codcom_v == `a'
	replace af_t = 21 if codcom_c == `a'
}
}
*

* Commute by Functional Areas
gen conm_af=(af_v!=af_t) & commute==1
label values conm_af yn
label var conm_af "Commuting by functional area"


*=============================
* Health
*=============================

* Subjective Health status
recode s8 (9=.), gen(shealth)
label var shealth "Subjective Health Status"
label define lshealth 1 "Very bad" 2 "Bad" 3 "Less than Regular" 4 "Regular" 5 "More than Regular" 6 "Good" 7 "Very Good"
label values shealth lshealth


* SAH
recode shealth (1/3 = 1 "Poor") (4 = 2 "Fair") (5 = 3 "Good") (6 = 4 "Very Good") (7 = 5 "Excellent"), gen(SAH)
label var SAH "Self-assessed health status, 5 categories"


*=============================
* Individual Variables
*=============================

* ID household
egen idh = group(folio)
label var idh "Id family"


* Age
rename edad age
label var age "Age"


* Recode gender variable
recode sex (1 = 1) (2 = 0), gen(male)
label var male "1 =  Male ,  0 = Female"
label define gender 0 "Female" 1 "Male"
label values male gender


* Number of Children
recode pco2 (3/5 = 1) (nonmissing = .), gen(children)
replace children=1 if children!=1 & pco1==3 | pco1==4 | pco1==5 
gen kid06  = 1 if (children == 1)&(age < 7)
gen kid717 = 1 if (children == 1)&(age > 6 & age < 18)

egen nkids06  = sum(kid06), by(idh)
egen nkids717 = sum(kid717), by(idh) 
label var nkids06  "Number of Children between 0 and 6 in the household"
label var nkids717 "Number of Children between 7 and 17 in the household"


* Civil Status
recode ecivil (1 2 = 1 "Married or Living in Couple") ///
              (3 4 5 6= 2 "Separated/divorced/Widowed") ///
			  (7 = 3 "Single"), gen(civil)
label var civil "Marital Status"


* Couple
gen couple=1 if civil==1
replace couple=0 if civil==2 | civil==3
label var couple "1: Couple, 0: Single"
label define couple 1 "Couple" 0 "Single"
label value couple couple


* Schooling
rename esc sch
label var sch "Schooling in years"


*=============================
* Works
*=============================

* Activity
recode activ (1 = 1 "Employed") (2 = 2 "Unemployed") (3 = 3 "Inactive"), gen(act)
label var act "Activity"


* Wage
rename yopraj wage     
label var wage "Montly income from the main occupation"


* Log of wage
gen lwage=log(wage)
label var lwage "Log of Montly income from the main occupation"


* Self-employed
gen self_employed=(o23==2)
label var self_employed "Self-employed"


* Occupation
recode oficio 	(1 = 1 "Miembros del Poder Ejecutivo y de los Cuerpos Legislativo y Personal Directivo de la Administración Pública y de Empresas") ///
				(2 = 2 "Profesionales científicos e intelectuales") ///
				(3 = 3 "Técnicos y Profesionales de Nivel Medio") ///
				(4 = 4 "Empleados de Oficina") ///
				(5 = 5 "Trabajadores de los Servicios y Vendedores de Comercios y Mercados") ///
				(6 = 6 "Agricultores y Trabajadores Calificados Agropecuarios y Pesqueros") ///
				(7 = 7 "Oficiales, Operarios y Artesanos de Artes Mecánicas y de Otros Oficios") ///
				(8 = 8 "Operadores de Instalaciones y Maquinas y Montadores") ///
				(9 = 9 "Trabajadores No Calificados") ///
				(0 = 10 "Fuerzas Armadas") ///
				(10 = 0 "Ocupación no bien específicada") ///
				(9999 = .) ///
				, gen(occupation)
label var occupation "Occupation"


* Skill Occupation
gen h_skill = (occupation==1 | occupation==2 | occupation==3)
label var h_skill "High Skill Occupation"
gen m_skill = (occupation==4 | occupation==5 | occupation==6)
label var m_skill "Medium Skill Occupation"
gen l_skill = (occupation>6 & occupation<11) 
label var l_skill "Low Skill Occupation"


* Ramas de actividad 
recode rama     (0 = 0 "Actividades No Bien Especificadas") ///
				(1 = 1 "Agricultura, Caza y Silvicultura") ///
				(2 = 2 "Explotación Minas y Canteras") ///
				(3 = 3 "Industrias Manufactureras") ///
				(4 = 4 "Electricidad, Gas y Agua") ///
				(5 = 5 "Construcción") ///
				(6 = 6 "Comercio Mayor/Menor Restaurantes - Hoteles") ///
				(7 = 7 "Transporte y Comunicaciones") ///
				(8 = 8 "Establecimientos Financieros Seguros") ///
				(9 = 9 "Servicios Comunales Sociales") ///
				, gen(ramas)
label var ramas "Ramas de Actividad"


* Actividades primarias, secundarias y terciarias
gen primario  =(ramas==1|ramas==2)
label var primario "Actividades Primarias"
gen secundario=(ramas==3|ramas==4|ramas==5)
label var secundario "Actividades Secundarias"
gen terciario =(ramas>5)
label var terciario "Actividades Terciarias"


* Participation in organizations or groups
gen part_org=(t18a!=16 & t18a!=.)
label var part_org "Do you currently participate in any organization?"
label values part_org yn


*==========================================================
* Merge with the database of time and distance
*==========================================================

merge m:1 codcom_v codcom_c using "$works/dist_api.dta", keepusing(dist dist_af)
drop if _m==2
drop _m

merge m:1 codcom_v codcom_c using "$works/time_api.dta", keepusing(time time_af)
drop if _m==2
drop _m


*==========================================================
* Distance and Time Commuting
*==========================================================

* Log of distance
gen logdist=log(dist)
label var logdist "Log of distance"


* Log of distance (Functional Areas)
gen logdist_af=log(dist_af)
label var logdist_af "Log of distance af"  


* Log of time
gen logtime=log(time)
label var logtime "Log of time"


* Log of time (Functional Areas)
gen logtime_af=log(time_af)
label var logtime_af "Log of time af"


* Ordered distance
gen     odist=1 if dist==0 
replace odist=2 if dist>0 & dist<=5
replace odist=3 if dist>5  & dist<=10
replace odist=4 if dist>10 & dist<=50
replace odist=5 if dist>50 & dist<=100
replace odist=6 if dist>100 & dist<=200
replace odist=7 if dist>200 & dist<=500
replace odist=8 if dist>500 
label var odist "Ordered distance"
label define odist 1 "CT =0" 2 "CT >0-5" 3 "CT >5-10" 4 "CT >10-50" 5 "CT >50-100" 6 "CT >100-200" 7 "CT >200-500" 8 ">500"
label values odist odist


sort segmento idviv hogar o

* Keep variables
keep segmento-comuna expr_p expp_p expc_p age sch wage codreg_v-conm_af SAH male nkids06-odist

order segmento-folio region-comuna urban expr_p expp_p expc_p age sch male-couple SAH act wage lwage-part_org r_norte-r_sur ///
codreg_v codreg_c commute_reg codprov_v codprov_c commute_prov codcom_v codcom_c commute dist logdist odist time logtime af_v-conm_af dist_af logdist_af time_af logtime_af


*Drop foreign commute (16) and 99999 (They appear in CASEN 2009)
drop if codcom_c==16001 | codcom_c==16002 | codcom_c==16006 | codcom_c==16012 | codcom_c==16021 | codcom_c==99999 


* Filters
keep if act==1
drop if occupation==0
drop if ramas==0
drop if wage==.
drop if SAH==.
drop if self_employed==1
drop if age<18 | age>65
keep if commute==1 
drop if odist==1 // Estas observaciones parecen ser que han sido mal tipeadas en la CASEN porque aparecen mismas comunas donde vive y trabajo. Eso es dato mismo de la CASEN


tab commute
tab conm_af


*=============================
* Save Data
*=============================
save    "$works/base_vf.dta", replace
saveold "$works/base_v12.dta", replace v(12)  // 17456
