################################################# #
# Latent class models and Willingness to Accept 
# for Time Commuting
################################################# #

rm(list = ls(all = TRUE))
setwd("/Users/juanpalomino/Dropbox/Tesis MCR - Juan Palomino/Programs/PIRS/Scripts")

source("max_ord_lc.R")
library("foreign")
library("Rchoice")
data <- read.dta("/Users/juanpalomino/Dropbox/Tesis MCR - Juan Palomino/Programs/PIRS/Works/base_v12.dta", convert.factors = FALSE)

# Reescalando variables
data$d_age    <- data$age / 10
data$d2_age   <- (data$age / 10) ^ 2
data$d_sch    <- data$sch / 10
data$c_age    <- data$age / 100
data$c2_age   <- (data$age / 100) ^ 2
data$c_sch    <- data$sch / 100
data$c_mhours <- data$mhours / 1000
data$c_nkids06  <- data$nkids06 / 10
data$c_nkids717 <- data$nkids717 / 10
data$male_couple      <- data$male * data$couple


#####################################################
# Class 2  with covariates in the probabilities ----
#####################################################
class2_bfgs <- ord_lc(SAH ~ logtime + lwage +
                        c_age + c2_age + male + c_sch + couple + c_nkids06 + c_nkids717 + 
                        h_skill + m_skill + secundario + terciario +
                        r_norte + r_sur + urban | 
                        c_age + male + couple + male_couple + part_org + urban,
                      data = data, 
                      Q = 2, 
                      panel = FALSE, 
                      index = NULL, 
                      gradient = TRUE, 
                      print.level = 2,  
                      iterlim = 1000, 
                      method = "BFGS")
summary(class2_bfgs)


library("car")

## Thresholds as stata
k1_c1 <- -coef(class2_bfgs)["class.1.constant"]
linearHypothesis(class2_bfgs, "-class.1.constant", test = "F")
k2_c1 <- coef(class2_bfgs)["class.1.kappa.1"] - coef(class2_bfgs)["class.1.constant"]
linearHypothesis(class2_bfgs, "class.1.kappa.1 - class.1.constant", verbose = TRUE)
k3_c1 <- coef(class2_bfgs)["class.1.kappa.2"] - coef(class2_bfgs)["class.1.constant"]
k4_c1 <- coef(class2_bfgs)["class.1.kappa.3"] - coef(class2_bfgs)["class.1.constant"]


k1_c2 <- -coef(class2_bfgs)["class.2.constant"]
linearHypothesis(class2_bfgs, "-class.2.constant", test = "F")
k2_c2 <- coef(class2_bfgs)["class.2.kappa.1"] - coef(class2_bfgs)["class.2.constant"]
linearHypothesis(class2_bfgs, "class.1.kappa.1 - class.2.constant", verbose = TRUE)
k3_c2 <- coef(class2_bfgs)["class.2.kappa.2"] - coef(class2_bfgs)["class.2.constant"]
k4_c2 <- coef(class2_bfgs)["class.2.kappa.3"] - coef(class2_bfgs)["class.2.constant"]

c(k1_c1, k2_c1, k3_c1, k4_c1)
c(k1_c2, k2_c2, k3_c2, k4_c2)



#------------------------------------------
# Proportion of individuals in each class
#------------------------------------------
wic <- class2_bfgs$Qic 
rowSums(wic)
n_sample <- length(apply(wic, 1, function(x) which(x == max(x))))
n_class  <-table(apply(wic, 1, function(x) which(x == max(x)))) / nrow(class2_bfgs$gradientObs)
n_class1 <- n_sample*n_class[c(1)]
n_class2 <- n_sample*n_class[c(2)]


#-------
# Mean
#-------
mean_wage <- mean(data[["wage"]])
mean_time <- mean(data[["time"]])


#------------------------------------------
# Willingness to Accept For Commuting Time
#------------------------------------------
library("msm")
coef(class2_bfgs)

# Class 1
cv_1b <- - (coef(class2_bfgs)["class.1.logtime"] * mean_wage) /(coef(class2_bfgs)["class.1.lwage"] * mean_time)
cv_1b_se <- deltamethod( ~ - (x8 * mean_wage) / (x9 * mean_time), 
                         mean = coef(class2_bfgs),
                         cov = vcov(class2_bfgs), 
                         ses = TRUE)
u_1b <- cv_1b + (1.64*cv_1b_se)
l_1b <- cv_1b - (1.64*cv_1b_se)
p_1b <- 2 * (1- pnorm(cv_1b / cv_1b_se))


# Class 2
cv_2b <- - (coef(class2_bfgs)["class.2.logtime"] * mean_wage) /(coef(class2_bfgs)["class.2.lwage"] * mean_time)

cv_2b_se <- deltamethod( ~ - (x25 * mean_wage) / (x26 * mean_time), 
                         mean = coef(class2_bfgs),
                         cov = vcov(class2_bfgs), 
                         ses = TRUE)
u_2b <- cv_2b + (1.64*cv_2b_se)
l_2b <- cv_2b - (1.64*cv_2b_se)
p_2b <- 2 * (1- pnorm(cv_2b / cv_2b_se))

# 99%: 2.58; 95%: 1.96; 90%: 1.64

AIC(class2_bfgs)
BIC(class2_bfgs)
c(k1_c1, k2_c1, k3_c1, k4_c1)
c(k1_c2, k2_c2, k3_c2, k4_c2)
c(n_sample, n_class1, n_class2)
n_class
c(mean_wage, mean_time)
c(cv_1b, cv_1b_se, l_1b, u_1b, p_1b)
c(cv_2b, cv_2b_se, l_2b, u_2b, p_2b)